@@ -1,5 +1,5 @@
+from .build_schema import build_schema, build_schema_from_file  # noqa
 from .enum import enum_type  # noqa
 from .resolver import field_resolver, mutate, query, subscribe, type_resolver  # noqa
 from .scalar import scalar_type  # noqa
-from .subscribe.with_filter import with_filter  # noqa
 from .utils import gql  # noqa
